@@ -78,6 +78,8 @@ Mount::Mount()
 
     // QML Stuff
     m_BaseView = new QQuickView();
+
+#if 0
     QString MountBox_Location;
 #if defined(Q_OS_OSX)
     MountBox_Location = QCoreApplication::applicationDirPath() + "/../Resources/data/ekos/mount/qml/mountbox.qml";
@@ -90,6 +92,10 @@ Mount::Mount()
 #endif
 
     m_BaseView->setSource(QUrl::fromLocalFile(MountBox_Location));
+#endif
+
+    m_BaseView->setSource(QUrl("qrc:/qml/mount/mountbox.qml"));
+
     m_BaseView->setTitle(i18n("Mount Control"));
 #ifdef Q_OS_OSX
     m_BaseView->setFlags(Qt::Tool | Qt::WindowStaysOnTopHint);
@@ -894,12 +900,25 @@ void Mount::setGPS(ISD::GDInterface *newGPS)
     if (newGPS == currentGPS)
         return;
 
+    //Options::setUseComputerSource(false);
+    //Options::setUseDeviceSource(true);
+
+    if (Options::useGPSSource() == false && KMessageBox::questionYesNo(KStars::Instance(),
+                               i18n("GPS is detected. Do you want to switch time and location source to GPS?"),
+                               i18n("GPS Settings"), KStandardGuiItem::yes(), KStandardGuiItem::no(),
+                               "use_gps_source_dialog") == KMessageBox::Yes)
+    {
+        Options::setUseKStarsSource(false);
+        Options::setUseMountSource(false);
+        Options::setUseGPSSource(true);
+    }
+
+    if (Options::useGPSSource() == false)
+        return;
+
     currentGPS = newGPS;
     connect(newGPS, SIGNAL(numberUpdated(INumberVectorProperty*)), this, SLOT(updateNumber(INumberVectorProperty*)), Qt::UniqueConnection);
 
-    Options::setUseComputerSource(false);
-    Options::setUseDeviceSource(true);
-
     appendLogText(i18n("GPS driver detected. KStars and mount time and location settings are now synced to the GPS driver."));
 
     syncGPS();
